/* Dbgtk.h
 * tromey Sat Jul 16 1994
 */

#ifndef DBG_TK_H
#define DBG_TK_H

#include "tcl.h"

EXTERN int Dbg_InitTk _ANSI_ARGS_ ((Tcl_Interp *));

#endif /* DBG_TK_H */
